@@ -123,6 +123,11 @@ agora_service_create_custom_video_track_frame = agora_lib.agora_service_create_c
 agora_service_create_custom_video_track_frame.restype = AGORA_HANDLE
 agora_service_create_custom_video_track_frame.argtypes = [AGORA_HANDLE, AGORA_HANDLE]
 
+agora_service_enable_extension = agora_lib.agora_service_enable_extension
+agora_service_enable_extension.restype = AGORA_API_C_INT
+agora_service_enable_extension.argtypes = [AGORA_HANDLE, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_uint]
+
+
 class SenderOptions(ctypes.Structure):
     _fields_ = [
         ("cc_mode", ctypes.c_int),
@@ -142,6 +147,8 @@ agora_service_create_custom_video_track_encoded.argtypes = [AGORA_HANDLE, AGORA_
 class AgoraService:
     def __init__(self) -> None:
         self.service_handle = agora_service_create()
+       
+        # set tag???
         self.inited = False
 
     def initialize(self, config: AgoraServiceConfig):       
@@ -153,6 +160,15 @@ class AgoraService:
             self.inited = True
         logger.debug(f'Initialization result: {result}')
 
+         # to enable plugin
+        provider = "agora.builtin"
+        generator = "agora_audio_label_generator"
+        cprovider = provider.encode('utf-8')
+        cgenerator = generator.encode('utf-8')
+        ctrak = ctypes.c_char_p(None)
+        #agora_service_enable_extension(self.service_handle, "agora.builtin", "agora_audio_label_generator", None, 1)
+        agora_service_enable_extension(self.service_handle, cprovider, cgenerator, ctrak, 1)
+
         if config.log_path:
             log_size = 512 * 1024
             if config.log_size > 0:
@@ -172,7 +188,7 @@ class AgoraService:
         self.inited = False
         self.service_handle = None
     
-    #createMediaNodeFactory	创建一个媒体节点工厂对象。
+    #createMediaNodeFactory: to create a medianode factory object
     def create_media_node_factory(self):
         if not self.inited:
             logger.error("AgoraService is not initialized. Please call initialize() first.")
@@ -193,8 +209,8 @@ class AgoraService:
         return RTCConnection(rtc_conn_handle)
 
 
-    #createCustomAudioTrackPcm	创建一个自定义音频Track。
-    def create_custom_audio_track_pcm(self, audio_pcm_data_sender:AudioPcmDataSender):
+    #createCustomAudioTrackPcm: creatae a custom audio track from pcm data sender
+    def create_custom_audio_track_pcm(self, audio_pcm_data_sender:AudioPcmDataSender) -> LocalAudioTrack | None:
         if not self.inited:
             logger.error("AgoraService is not initialized. Please call initialize() first.")
             return None
